"""
Python module generated from Java source file java.util.AbstractSet

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import *
from typing import Any, Callable, Iterable, Tuple


class AbstractSet(AbstractCollection, Set):

    def equals(self, o: "Object") -> bool:
        """
        Compares the specified object with this set for equality.  Returns
        `True` if the given object is also a set, the two sets have
        the same size, and every member of the given set is contained in
        this set.  This ensures that the `equals` method works
        properly across different implementations of the `Set`
        interface.
        
        This implementation first checks if the specified object is this
        set; if so it returns `True`.  Then, it checks if the
        specified object is a set whose size is identical to the size of
        this set; if not, it returns False.  If so, it returns
        `containsAll((Collection) o)`.

        Arguments
        - o: object to be compared for equality with this set

        Returns
        - `True` if the specified object is equal to this set
        """
        ...


    def hashCode(self) -> int:
        """
        Returns the hash code value for this set.  The hash code of a set is
        defined to be the sum of the hash codes of the elements in the set,
        where the hash code of a `null` element is defined to be zero.
        This ensures that `s1.equals(s2)` implies that
        `s1.hashCode()==s2.hashCode()` for any two sets `s1`
        and `s2`, as required by the general contract of
        Object.hashCode.
        
        This implementation iterates over the set, calling the
        `hashCode` method on each element in the set, and adding up
        the results.

        Returns
        - the hash code value for this set

        See
        - Set.equals(Object)
        """
        ...


    def removeAll(self, c: Iterable[Any]) -> bool:
        """
        Removes from this set all of its elements that are contained in the
        specified collection (optional operation).  If the specified
        collection is also a set, this operation effectively modifies this
        set so that its value is the *asymmetric set difference* of
        the two sets.
        
        This implementation determines which is the smaller of this set
        and the specified collection, by invoking the `size`
        method on each.  If this set has fewer elements, then the
        implementation iterates over this set, checking each element
        returned by the iterator in turn to see if it is contained in
        the specified collection.  If it is so contained, it is removed
        from this set with the iterator's `remove` method.  If
        the specified collection has fewer elements, then the
        implementation iterates over the specified collection, removing
        from this set each element returned by the iterator, using this
        set's `remove` method.
        
        Note that this implementation will throw an
        `UnsupportedOperationException` if the iterator returned by the
        `iterator` method does not implement the `remove` method.

        Arguments
        - c: collection containing elements to be removed from this set

        Returns
        - `True` if this set changed as a result of the call

        Raises
        - UnsupportedOperationException: if the `removeAll` operation
                is not supported by this set
        - ClassCastException: if the class of an element of this set
                is incompatible with the specified collection
        (<a href="Collection.html#optional-restrictions">optional</a>)
        - NullPointerException: if this set contains a null element and the
                specified collection does not permit null elements
        (<a href="Collection.html#optional-restrictions">optional</a>),
                or if the specified collection is null

        See
        - .contains(Object)
        """
        ...



"""
Python module generated from Java source file com.google.common.util.concurrent.ForwardingBlockingQueue

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.collect import ForwardingQueue
from com.google.common.util.concurrent import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.util.concurrent import BlockingQueue
from java.util.concurrent import TimeUnit
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class ForwardingBlockingQueue(ForwardingQueue, BlockingQueue):
    """
    A BlockingQueue which forwards all its method calls to another BlockingQueue.
    Subclasses should override one or more methods to modify the behavior of the backing collection
    as desired per the <a href="http://en.wikipedia.org/wiki/Decorator_pattern">decorator
    pattern</a>.
    
    **`default` method warning:** This class does *not* forward calls to `default` methods. Instead, it inherits their default implementations. When those implementations
    invoke methods, they invoke methods on the `ForwardingBlockingQueue`.
    
    Type `<E>`: the type of elements held in this collection

    Author(s)
    - Raimundo Mirisola

    Since
    - 4.0
    """

    def drainTo(self, c: Iterable["E"], maxElements: int) -> int:
        ...


    def drainTo(self, c: Iterable["E"]) -> int:
        ...


    def offer(self, e: "E", timeout: int, unit: "TimeUnit") -> bool:
        ...


    def poll(self, timeout: int, unit: "TimeUnit") -> "E":
        ...


    def put(self, e: "E") -> None:
        ...


    def remainingCapacity(self) -> int:
        ...


    def take(self) -> "E":
        ...



"""
Python module generated from Java source file org.yaml.snakeyaml.external.com.google.gdata.util.common.base.PercentEscaper

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.yaml.snakeyaml.external.com.google.gdata.util.common.base import *
from typing import Any, Callable, Iterable, Tuple


class PercentEscaper(UnicodeEscaper):
    """
    A `UnicodeEscaper` that escapes some set of Java characters using the URI percent encoding
    scheme. The set of safe characters (those which remain unescaped) can be specified on
    construction.
    
    
    For details on escaping URIs for use in web pages, see section 2.4 of
    <a href="http://www.ietf.org/rfc/rfc3986.txt">RFC 3986</a>.
    
    
    In most cases this class should not need to be used directly. If you have no special requirements
    for escaping your URIs, you should use either CharEscapers.uriEscaper() or
    CharEscapers.uriEscaper(boolean).
    
    
    When encoding a String, the following rules apply:
    
    - The alphanumeric characters "a" through "z", "A" through "Z" and "0" through "9" remain the
    same.
    - Any additionally specified safe characters remain the same.
    - If `plusForSpace` was specified, the space character " " is converted into a plus sign
    "+".
    - All other characters are converted into one or more bytes using UTF-8 encoding and each byte
    is then represented by the 3-character string "%XY", where "XY" is the two-digit, uppercase,
    hexadecimal representation of the byte value.
    
    
    
    RFC 2396 specifies the set of unreserved characters as "-", "_", ".", "!", "~", "*", "'", "(" and
    ")". It goes on to state:
    
    
    *Unreserved characters can be escaped without changing the semantics of the URI, but this
    should not be done unless the URI is being used in a context that does not allow the unescaped
    character to appear.*
    
    
    For performance reasons the only currently supported character encoding of this class is UTF-8.
    
    
    **Note**: This escaper produces uppercase hexidecimal sequences. From
    <a href="http://www.ietf.org/rfc/rfc3986.txt">RFC 3986</a>:
    *"URI producers and normalizers should use uppercase hexadecimal digits for all
    percent-encodings."*
    """

    SAFECHARS_URLENCODER = "-_.*"
    """
    A string of safe characters that mimics the behavior of java.net.URLEncoder.
    """
    SAFEPATHCHARS_URLENCODER = "-_.!~*'()@:$&,;="
    """
    A string of characters that do not need to be encoded when used in URI path segments, as
    specified in RFC 3986. Note that some of these characters do need to be escaped when used in
    other parts of the URI.
    """
    SAFEQUERYSTRINGCHARS_URLENCODER = "-_.!~*'()@:$,;/?:"
    """
    A string of characters that do not need to be encoded when used in URI query strings, as
    specified in RFC 3986. Note that some of these characters do need to be escaped when used in
    other parts of the URI.
    """


    def __init__(self, safeChars: str, plusForSpace: bool):
        """
        Constructs a URI escaper with the specified safe characters and optional handling of the space
        character.

        Arguments
        - safeChars: a non null string specifying additional safe characters for this escaper (the
               ranges 0..9, a..z and A..Z are always safe and should not be specified here)
        - plusForSpace: True if ASCII space should be escaped to `+` rather than `%20`

        Raises
        - IllegalArgumentException: if any of the parameters were invalid
        """
        ...


    def escape(self, s: str) -> str:
        ...



"""
Python module generated from Java source file org.bukkit.event.EventException

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.event import *
from typing import Any, Callable, Iterable, Tuple


class EventException(Exception):

    def __init__(self, throwable: "Throwable"):
        """
        Constructs a new EventException based on the given Exception

        Arguments
        - throwable: Exception that triggered this Exception
        """
        ...


    def __init__(self):
        """
        Constructs a new EventException
        """
        ...


    def __init__(self, cause: "Throwable", message: str):
        """
        Constructs a new EventException with the given message

        Arguments
        - cause: The exception that caused this
        - message: The message
        """
        ...


    def __init__(self, message: str):
        """
        Constructs a new EventException with the given message

        Arguments
        - message: The message
        """
        ...


    def getCause(self) -> "Throwable":
        """
        If applicable, returns the Exception that triggered this Exception

        Returns
        - Inner exception, or null if one does not exist
        """
        ...



"""
Python module generated from Java source file java.io.FileInputStream

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.io import *
from java.util import Arrays
from jdk.internal.util import ArraysSupport
from sun.nio.ch import FileChannelImpl
from typing import Any, Callable, Iterable, Tuple


class FileInputStream(InputStream):
    """
    A `FileInputStream` obtains input bytes
    from a file in a file system. What files
    are  available depends on the host environment.
    
    `FileInputStream` is meant for reading streams of raw bytes
    such as image data. For reading streams of characters, consider using
    `FileReader`.

    Author(s)
    - Arthur van Hoff

    See
    - java.nio.file.Files.newInputStream

    Since
    - 1.0

    Unknown Tags
    - To release resources used by this stream .close should be called
    directly or by try-with-resources. Subclasses are responsible for the cleanup
    of resources acquired by the subclass.
    Subclasses that override .finalize in order to perform cleanup
    should be modified to use alternative cleanup mechanisms such as
    java.lang.ref.Cleaner and remove the overriding `finalize` method.
    - If this FileInputStream has been subclassed and the .close
    method has been overridden, the .close method will be
    called when the FileInputStream is unreachable.
    Otherwise, it is implementation specific how the resource cleanup described in
    .close is performed.
    """

    def __init__(self, name: str):
        """
        Creates a `FileInputStream` by
        opening a connection to an actual file,
        the file named by the path name `name`
        in the file system.  A new `FileDescriptor`
        object is created to represent this file
        connection.
        
        First, if there is a security
        manager, its `checkRead` method
        is called with the `name` argument
        as its argument.
        
        If the named file does not exist, is a directory rather than a regular
        file, or for some other reason cannot be opened for reading then a
        `FileNotFoundException` is thrown.

        Arguments
        - name: the system-dependent file name.

        Raises
        - FileNotFoundException: if the file does not exist,
                    is a directory rather than a regular file,
                    or for some other reason cannot be opened for
                    reading.
        - SecurityException: if a security manager exists and its
                    `checkRead` method denies read access
                    to the file.

        See
        - java.lang.SecurityManager.checkRead(java.lang.String)
        """
        ...


    def __init__(self, file: "File"):
        """
        Creates a `FileInputStream` by
        opening a connection to an actual file,
        the file named by the `File`
        object `file` in the file system.
        A new `FileDescriptor` object
        is created to represent this file connection.
        
        First, if there is a security manager,
        its `checkRead` method  is called
        with the path represented by the `file`
        argument as its argument.
        
        If the named file does not exist, is a directory rather than a regular
        file, or for some other reason cannot be opened for reading then a
        `FileNotFoundException` is thrown.

        Arguments
        - file: the file to be opened for reading.

        Raises
        - FileNotFoundException: if the file does not exist,
                    is a directory rather than a regular file,
                    or for some other reason cannot be opened for
                    reading.
        - SecurityException: if a security manager exists and its
                    `checkRead` method denies read access to the file.

        See
        - java.lang.SecurityManager.checkRead(java.lang.String)
        """
        ...


    def __init__(self, fdObj: "FileDescriptor"):
        """
        Creates a `FileInputStream` by using the file descriptor
        `fdObj`, which represents an existing connection to an
        actual file in the file system.
        
        If there is a security manager, its `checkRead` method is
        called with the file descriptor `fdObj` as its argument to
        see if it's ok to read the file descriptor. If read access is denied
        to the file descriptor a `SecurityException` is thrown.
        
        If `fdObj` is null then a `NullPointerException`
        is thrown.
        
        This constructor does not throw an exception if `fdObj`
        is java.io.FileDescriptor.valid() invalid.
        However, if the methods are invoked on the resulting stream to attempt
        I/O on the stream, an `IOException` is thrown.

        Arguments
        - fdObj: the file descriptor to be opened for reading.

        Raises
        - SecurityException: if a security manager exists and its
                    `checkRead` method denies read access to the
                    file descriptor.

        See
        - SecurityManager.checkRead(java.io.FileDescriptor)
        """
        ...


    def read(self) -> int:
        """
        Reads a byte of data from this input stream. This method blocks
        if no input is yet available.

        Returns
        - the next byte of data, or `-1` if the end of the
                    file is reached.

        Raises
        - IOException: if an I/O error occurs.
        """
        ...


    def read(self, b: list[int]) -> int:
        """
        Reads up to `b.length` bytes of data from this input
        stream into an array of bytes. This method blocks until some input
        is available.

        Arguments
        - b: the buffer into which the data is read.

        Returns
        - the total number of bytes read into the buffer, or
                    `-1` if there is no more data because the end of
                    the file has been reached.

        Raises
        - IOException: if an I/O error occurs.
        """
        ...


    def read(self, b: list[int], off: int, len: int) -> int:
        """
        Reads up to `len` bytes of data from this input stream
        into an array of bytes. If `len` is not zero, the method
        blocks until some input is available; otherwise, no
        bytes are read and `0` is returned.

        Arguments
        - b: the buffer into which the data is read.
        - off: the start offset in the destination array `b`
        - len: the maximum number of bytes read.

        Returns
        - the total number of bytes read into the buffer, or
                    `-1` if there is no more data because the end of
                    the file has been reached.

        Raises
        - NullPointerException: If `b` is `null`.
        - IndexOutOfBoundsException: If `off` is negative,
                    `len` is negative, or `len` is greater than
                    `b.length - off`
        - IOException: if an I/O error occurs.
        """
        ...


    def readAllBytes(self) -> list[int]:
        ...


    def readNBytes(self, len: int) -> list[int]:
        ...


    def skip(self, n: int) -> int:
        """
        Skips over and discards `n` bytes of data from the
        input stream.
        
        The `skip` method may, for a variety of
        reasons, end up skipping over some smaller number of bytes,
        possibly `0`. If `n` is negative, the method
        will try to skip backwards. In case the backing file does not support
        backward skip at its current position, an `IOException` is
        thrown. The actual number of bytes skipped is returned. If it skips
        forwards, it returns a positive value. If it skips backwards, it
        returns a negative value.
        
        This method may skip more bytes than what are remaining in the
        backing file. This produces no exception and the number of bytes skipped
        may include some number of bytes that were beyond the EOF of the
        backing file. Attempting to read from the stream after skipping past
        the end will result in -1 indicating the end of the file.

        Arguments
        - n: the number of bytes to be skipped.

        Returns
        - the actual number of bytes skipped.

        Raises
        - IOException: if n is negative, if the stream does not
                    support seek, or if an I/O error occurs.
        """
        ...


    def available(self) -> int:
        """
        Returns an estimate of the number of remaining bytes that can be read (or
        skipped over) from this input stream without blocking by the next
        invocation of a method for this input stream. Returns 0 when the file
        position is beyond EOF. The next invocation might be the same thread
        or another thread. A single read or skip of this many bytes will not
        block, but may read or skip fewer bytes.
        
         In some cases, a non-blocking read (or skip) may appear to be
        blocked when it is merely slow, for example when reading large
        files over slow networks.

        Returns
        - an estimate of the number of remaining bytes that can be read
                    (or skipped over) from this input stream without blocking.

        Raises
        - IOException: if this file input stream has been closed by calling
                    `close` or an I/O error occurs.
        """
        ...


    def close(self) -> None:
        """
        Closes this file input stream and releases any system resources
        associated with the stream.
        
         If this stream has an associated channel then the channel is closed
        as well.

        Raises
        - IOException: if an I/O error occurs.

        Unknown Tags
        - Overriding .close to perform cleanup actions is reliable
        only when called directly or when called by try-with-resources.
        Do not depend on finalization to invoke `close`;
        finalization is not reliable and is deprecated.
        If cleanup of native resources is needed, other mechanisms such as
        java.lang.ref.Cleaner should be used.
        - 1.4
        """
        ...


    def getFD(self) -> "FileDescriptor":
        """
        Returns the `FileDescriptor`
        object  that represents the connection to
        the actual file in the file system being
        used by this `FileInputStream`.

        Returns
        - the file descriptor object associated with this stream.

        Raises
        - IOException: if an I/O error occurs.

        See
        - java.io.FileDescriptor
        """
        ...


    def getChannel(self) -> "FileChannel":
        """
        Returns the unique java.nio.channels.FileChannel FileChannel
        object associated with this file input stream.
        
         The initial java.nio.channels.FileChannel.position()
        position of the returned channel will be equal to the
        number of bytes read from the file so far.  Reading bytes from this
        stream will increment the channel's position.  Changing the channel's
        position, either explicitly or by reading, will change this stream's
        file position.

        Returns
        - the file channel associated with this file input stream

        Since
        - 1.4
        """
        ...



"""
Python module generated from Java source file org.bukkit.block.banner.PatternType

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from com.google.common.collect import Lists
from java.util import Locale
from org.bukkit import Keyed
from org.bukkit import NamespacedKey
from org.bukkit import Registry
from org.bukkit.block.banner import *
from org.bukkit.registry import RegistryAware
from org.bukkit.util import OldEnum
from typing import Any, Callable, Iterable, Tuple


class PatternType(OldEnum, Keyed, RegistryAware):

    BASE = getType("base")
    SQUARE_BOTTOM_LEFT = getType("square_bottom_left")
    SQUARE_BOTTOM_RIGHT = getType("square_bottom_right")
    SQUARE_TOP_LEFT = getType("square_top_left")
    SQUARE_TOP_RIGHT = getType("square_top_right")
    STRIPE_BOTTOM = getType("stripe_bottom")
    STRIPE_TOP = getType("stripe_top")
    STRIPE_LEFT = getType("stripe_left")
    STRIPE_RIGHT = getType("stripe_right")
    STRIPE_CENTER = getType("stripe_center")
    STRIPE_MIDDLE = getType("stripe_middle")
    STRIPE_DOWNRIGHT = getType("stripe_downright")
    STRIPE_DOWNLEFT = getType("stripe_downleft")
    SMALL_STRIPES = getType("small_stripes")
    CROSS = getType("cross")
    STRAIGHT_CROSS = getType("straight_cross")
    TRIANGLE_BOTTOM = getType("triangle_bottom")
    TRIANGLE_TOP = getType("triangle_top")
    TRIANGLES_BOTTOM = getType("triangles_bottom")
    TRIANGLES_TOP = getType("triangles_top")
    DIAGONAL_LEFT = getType("diagonal_left")
    DIAGONAL_UP_RIGHT = getType("diagonal_up_right")
    DIAGONAL_UP_LEFT = getType("diagonal_up_left")
    DIAGONAL_RIGHT = getType("diagonal_right")
    CIRCLE = getType("circle")
    RHOMBUS = getType("rhombus")
    HALF_VERTICAL = getType("half_vertical")
    HALF_HORIZONTAL = getType("half_horizontal")
    HALF_VERTICAL_RIGHT = getType("half_vertical_right")
    HALF_HORIZONTAL_BOTTOM = getType("half_horizontal_bottom")
    BORDER = getType("border")
    CURLY_BORDER = getType("curly_border")
    CREEPER = getType("creeper")
    GRADIENT = getType("gradient")
    GRADIENT_UP = getType("gradient_up")
    BRICKS = getType("bricks")
    SKULL = getType("skull")
    FLOWER = getType("flower")
    MOJANG = getType("mojang")
    GLOBE = getType("globe")
    PIGLIN = getType("piglin")
    FLOW = getType("flow")
    GUSTER = getType("guster")


    def getKey(self) -> "NamespacedKey":
        """
        See
        - .isRegistered()

        Deprecated
        - A key might not always be present, use .getKeyOrThrow() instead.
        """
        ...


    def getIdentifier(self) -> str:
        """
        Returns the identifier used to represent
        this pattern type

        Returns
        - the pattern's identifier

        See
        - .getKey

        Deprecated
        - magic value
        """
        ...


    @staticmethod
    def getByIdentifier(identifier: str) -> "PatternType":
        """
        Returns the pattern type which matches the passed
        identifier or null if no matches are found

        Arguments
        - identifier: the identifier

        Returns
        - the matched pattern type or null

        See
        - Registry.BANNER_PATTERN

        Deprecated
        - magic value, use Registry.get(NamespacedKey) instead
        """
        ...


    @staticmethod
    def getType(key: str) -> "PatternType":
        ...


    @staticmethod
    def valueOf(name: str) -> "PatternType":
        """
        Arguments
        - name: of the pattern type.

        Returns
        - the pattern type with the given name.

        Deprecated
        - only for backwards compatibility, use Registry.get(NamespacedKey) instead.
        """
        ...


    @staticmethod
    def values() -> list["PatternType"]:
        """
        Returns
        - an array of all known pattern types.

        Deprecated
        - use Registry.iterator().
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.entity.ProjectileHitEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import Block
from org.bukkit.block import BlockFace
from org.bukkit.entity import Entity
from org.bukkit.entity import Projectile
from org.bukkit.event import Cancellable
from org.bukkit.event import HandlerList
from org.bukkit.event.entity import *
from typing import Any, Callable, Iterable, Tuple


class ProjectileHitEvent(EntityEvent, Cancellable):
    """
    Called when a projectile hits an object
    """

    def __init__(self, projectile: "Projectile"):
        ...


    def __init__(self, projectile: "Projectile", hitEntity: "Entity"):
        ...


    def __init__(self, projectile: "Projectile", hitBlock: "Block"):
        ...


    def __init__(self, projectile: "Projectile", hitEntity: "Entity", hitBlock: "Block"):
        ...


    def __init__(self, projectile: "Projectile", hitEntity: "Entity", hitBlock: "Block", hitFace: "BlockFace"):
        ...


    def getEntity(self) -> "Projectile":
        ...


    def getHitBlock(self) -> "Block":
        """
        Gets the block that was hit, if it was a block that was hit.

        Returns
        - hit block or else null
        """
        ...


    def getHitBlockFace(self) -> "BlockFace":
        """
        Gets the block face that was hit, if it was a block that was hit and the
        face was provided in the event.

        Returns
        - hit face or else null
        """
        ...


    def getHitEntity(self) -> "Entity":
        """
        Gets the entity that was hit, if it was an entity that was hit.

        Returns
        - hit entity or else null
        """
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        """
        Whether to cancel the action that occurs when the projectile hits.
        
        In the case of an entity, it will not collide (unless it's a firework,
        then use FireworkExplodeEvent).
        
        In the case of a block, some blocks (eg target block, bell) will not
        perform the action associated.
        
        This does NOT prevent block collisions, and explosions will still occur
        unless their respective events are cancelled.

        Arguments
        - cancel: True if you wish to cancel this event
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file com.google.common.collect.Count

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from java.io import Serializable
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class Count(Serializable):
    """
    A mutable value of type `int`, for multisets to use in tracking counts of values.

    Author(s)
    - Louis Wasserman
    """

    def get(self) -> int:
        ...


    def add(self, delta: int) -> None:
        ...


    def addAndGet(self, delta: int) -> int:
        ...


    def set(self, newValue: int) -> None:
        ...


    def getAndSet(self, newValue: int) -> int:
        ...


    def hashCode(self) -> int:
        ...


    def equals(self, obj: "Object") -> bool:
        ...


    def toString(self) -> str:
        ...



"""
Python module generated from Java source file org.bukkit.util.Transformation

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from java.util import Objects
from org.bukkit.util import *
from org.joml import AxisAngle4f
from org.joml import Quaternionf
from org.joml import Vector3f
from typing import Any, Callable, Iterable, Tuple


class Transformation:
    """
    Represents an arbitrary affine transformation.
    """

    def __init__(self, translation: "Vector3f", leftRotation: "AxisAngle4f", scale: "Vector3f", rightRotation: "AxisAngle4f"):
        ...


    def __init__(self, translation: "Vector3f", leftRotation: "Quaternionf", scale: "Vector3f", rightRotation: "Quaternionf"):
        ...


    def getTranslation(self) -> "Vector3f":
        """
        Gets the translation component of this transformation.

        Returns
        - translation component
        """
        ...


    def getLeftRotation(self) -> "Quaternionf":
        """
        Gets the left rotation component of this transformation.

        Returns
        - left rotation component
        """
        ...


    def getScale(self) -> "Vector3f":
        """
        Gets the scale component of this transformation.

        Returns
        - scale component
        """
        ...


    def getRightRotation(self) -> "Quaternionf":
        """
        Gets the right rotation component of this transformation.

        Returns
        - right rotation component
        """
        ...


    def hashCode(self) -> int:
        ...


    def equals(self, obj: "Object") -> bool:
        ...


    def toString(self) -> str:
        ...



"""
Python module generated from Java source file com.google.common.collect.DescendingImmutableSortedSet

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.collect import *
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class DescendingImmutableSortedSet(ImmutableSortedSet):
    """
    Skeletal implementation of ImmutableSortedSet.descendingSet().

    Author(s)
    - Louis Wasserman
    """

    def contains(self, object: "Object") -> bool:
        ...


    def size(self) -> int:
        ...


    def iterator(self) -> "UnmodifiableIterator"["E"]:
        ...


    def descendingSet(self) -> "ImmutableSortedSet"["E"]:
        ...


    def descendingIterator(self) -> "UnmodifiableIterator"["E"]:
        ...


    def lower(self, element: "E") -> "E":
        ...


    def floor(self, element: "E") -> "E":
        ...


    def ceiling(self, element: "E") -> "E":
        ...


    def higher(self, element: "E") -> "E":
        ...



"""
Python module generated from Java source file java.util.regex.Matcher

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util import ConcurrentModificationException
from java.util import Iterator
from java.util import NoSuchElementException
from java.util import Objects
from java.util import Spliterator
from java.util.function import Consumer
from java.util.function import Function
from java.util.regex import *
from java.util.stream import Stream
from java.util.stream import StreamSupport
from typing import Any, Callable, Iterable, Tuple


class Matcher(MatchResult):

    def pattern(self) -> "Pattern":
        """
        Returns the pattern that is interpreted by this matcher.

        Returns
        - The pattern for which this matcher was created
        """
        ...


    def toMatchResult(self) -> "MatchResult":
        """
        Returns the match state of this matcher as a MatchResult.
        The result is unaffected by subsequent operations performed upon this
        matcher.

        Returns
        - a `MatchResult` with the state of this matcher

        Since
        - 1.5
        """
        ...


    def usePattern(self, newPattern: "Pattern") -> "Matcher":
        """
        Changes the `Pattern` that this `Matcher` uses to
        find matches with.
        
         This method causes this matcher to lose information
        about the groups of the last match that occurred. The
        matcher's position in the input is maintained and its
        last append position is unaffected.

        Arguments
        - newPattern: The new pattern used by this matcher

        Returns
        - This matcher

        Raises
        - IllegalArgumentException: If newPattern is `null`

        Since
        - 1.5
        """
        ...


    def reset(self) -> "Matcher":
        """
        Resets this matcher.
        
         Resetting a matcher discards all of its explicit state information
        and sets its append position to zero. The matcher's region is set to the
        default region, which is its entire character sequence. The anchoring
        and transparency of this matcher's region boundaries are unaffected.

        Returns
        - This matcher
        """
        ...


    def reset(self, input: "CharSequence") -> "Matcher":
        """
        Resets this matcher with a new input sequence.
        
         Resetting a matcher discards all of its explicit state information
        and sets its append position to zero.  The matcher's region is set to
        the default region, which is its entire character sequence.  The
        anchoring and transparency of this matcher's region boundaries are
        unaffected.

        Arguments
        - input: The new input character sequence

        Returns
        - This matcher
        """
        ...


    def start(self) -> int:
        """
        Returns the start index of the previous match.

        Returns
        - The index of the first character matched

        Raises
        - IllegalStateException: If no match has yet been attempted,
                 or if the previous match operation failed
        """
        ...


    def start(self, group: int) -> int:
        """
        Returns the start index of the subsequence captured by the given group
        during the previous match operation.
        
         <a href="Pattern.html#cg">Capturing groups</a> are indexed from left
        to right, starting at one.  Group zero denotes the entire pattern, so
        the expression *m.*`start(0)` is equivalent to
        *m.*`start()`.  

        Arguments
        - group: The index of a capturing group in this matcher's pattern

        Returns
        - The index of the first character captured by the group,
                 or `-1` if the match was successful but the group
                 itself did not match anything

        Raises
        - IllegalStateException: If no match has yet been attempted,
                 or if the previous match operation failed
        - IndexOutOfBoundsException: If there is no capturing group in the pattern
                 with the given index
        """
        ...


    def start(self, name: str) -> int:
        """
        Returns the start index of the subsequence captured by the given
        <a href="Pattern.html#groupname">named-capturing group</a> during the
        previous match operation.

        Arguments
        - name: The name of a named-capturing group in this matcher's pattern

        Returns
        - The index of the first character captured by the group,
                 or `-1` if the match was successful but the group
                 itself did not match anything

        Raises
        - IllegalStateException: If no match has yet been attempted,
                 or if the previous match operation failed
        - IllegalArgumentException: If there is no capturing group in the pattern
                 with the given name

        Since
        - 1.8
        """
        ...


    def end(self) -> int:
        """
        Returns the offset after the last character matched.

        Returns
        - The offset after the last character matched

        Raises
        - IllegalStateException: If no match has yet been attempted,
                 or if the previous match operation failed
        """
        ...


    def end(self, group: int) -> int:
        """
        Returns the offset after the last character of the subsequence
        captured by the given group during the previous match operation.
        
         <a href="Pattern.html#cg">Capturing groups</a> are indexed from left
        to right, starting at one.  Group zero denotes the entire pattern, so
        the expression *m.*`end(0)` is equivalent to
        *m.*`end()`.  

        Arguments
        - group: The index of a capturing group in this matcher's pattern

        Returns
        - The offset after the last character captured by the group,
                 or `-1` if the match was successful
                 but the group itself did not match anything

        Raises
        - IllegalStateException: If no match has yet been attempted,
                 or if the previous match operation failed
        - IndexOutOfBoundsException: If there is no capturing group in the pattern
                 with the given index
        """
        ...


    def end(self, name: str) -> int:
        """
        Returns the offset after the last character of the subsequence
        captured by the given <a href="Pattern.html#groupname">named-capturing
        group</a> during the previous match operation.

        Arguments
        - name: The name of a named-capturing group in this matcher's pattern

        Returns
        - The offset after the last character captured by the group,
                 or `-1` if the match was successful
                 but the group itself did not match anything

        Raises
        - IllegalStateException: If no match has yet been attempted,
                 or if the previous match operation failed
        - IllegalArgumentException: If there is no capturing group in the pattern
                 with the given name

        Since
        - 1.8
        """
        ...


    def group(self) -> str:
        """
        Returns the input subsequence matched by the previous match.
        
         For a matcher *m* with input sequence *s*,
        the expressions *m.*`group()` and
        *s.*`substring(`*m.*`start(),`&nbsp;*m.*
        `end())` are equivalent.  
        
         Note that some patterns, for example `a*`, match the empty
        string.  This method will return the empty string when the pattern
        successfully matches the empty string in the input.  

        Returns
        - The (possibly empty) subsequence matched by the previous match,
                in string form

        Raises
        - IllegalStateException: If no match has yet been attempted,
                 or if the previous match operation failed
        """
        ...


    def group(self, group: int) -> str:
        """
        Returns the input subsequence captured by the given group during the
        previous match operation.
        
         For a matcher *m*, input sequence *s*, and group index
        *g*, the expressions *m.*`group(`*g*`)` and
        *s.*`substring(`*m.*`start(`*g*`),`&nbsp;*m.*`end(`*g*`))`
        are equivalent.  
        
         <a href="Pattern.html#cg">Capturing groups</a> are indexed from left
        to right, starting at one.  Group zero denotes the entire pattern, so
        the expression `m.group(0)` is equivalent to `m.group()`.
        
        
         If the match was successful but the group specified failed to match
        any part of the input sequence, then `null` is returned. Note
        that some groups, for example `(a*)`, match the empty string.
        This method will return the empty string when such a group successfully
        matches the empty string in the input.  

        Arguments
        - group: The index of a capturing group in this matcher's pattern

        Returns
        - The (possibly empty) subsequence captured by the group
                 during the previous match, or `null` if the group
                 failed to match part of the input

        Raises
        - IllegalStateException: If no match has yet been attempted,
                 or if the previous match operation failed
        - IndexOutOfBoundsException: If there is no capturing group in the pattern
                 with the given index
        """
        ...


    def group(self, name: str) -> str:
        """
        Returns the input subsequence captured by the given
        <a href="Pattern.html#groupname">named-capturing group</a> during the
        previous match operation.
        
         If the match was successful but the group specified failed to match
        any part of the input sequence, then `null` is returned. Note
        that some groups, for example `(a*)`, match the empty string.
        This method will return the empty string when such a group successfully
        matches the empty string in the input.  

        Arguments
        - name: The name of a named-capturing group in this matcher's pattern

        Returns
        - The (possibly empty) subsequence captured by the named group
                 during the previous match, or `null` if the group
                 failed to match part of the input

        Raises
        - IllegalStateException: If no match has yet been attempted,
                 or if the previous match operation failed
        - IllegalArgumentException: If there is no capturing group in the pattern
                 with the given name

        Since
        - 1.7
        """
        ...


    def groupCount(self) -> int:
        """
        Returns the number of capturing groups in this matcher's pattern.
        
         Group zero denotes the entire pattern by convention. It is not
        included in this count.
        
         Any non-negative integer smaller than or equal to the value
        returned by this method is guaranteed to be a valid group index for
        this matcher.  

        Returns
        - The number of capturing groups in this matcher's pattern
        """
        ...


    def matches(self) -> bool:
        """
        Attempts to match the entire region against the pattern.
        
         If the match succeeds then more information can be obtained via the
        `start`, `end`, and `group` methods.  

        Returns
        - `True` if, and only if, the entire region sequence
                 matches this matcher's pattern
        """
        ...


    def find(self) -> bool:
        """
        Attempts to find the next subsequence of the input sequence that matches
        the pattern.
        
         This method starts at the beginning of this matcher's region, or, if
        a previous invocation of the method was successful and the matcher has
        not since been reset, at the first character not matched by the previous
        match.
        
         If the match succeeds then more information can be obtained via the
        `start`, `end`, and `group` methods.  

        Returns
        - `True` if, and only if, a subsequence of the input
                 sequence matches this matcher's pattern
        """
        ...


    def find(self, start: int) -> bool:
        """
        Resets this matcher and then attempts to find the next subsequence of
        the input sequence that matches the pattern, starting at the specified
        index.
        
         If the match succeeds then more information can be obtained via the
        `start`, `end`, and `group` methods, and subsequent
        invocations of the .find() method will start at the first
        character not matched by this match.  

        Arguments
        - start: the index to start searching for a match

        Returns
        - `True` if, and only if, a subsequence of the input
                 sequence starting at the given index matches this matcher's
                 pattern

        Raises
        - IndexOutOfBoundsException: If start is less than zero or if start is greater than the
                 length of the input sequence.
        """
        ...


    def lookingAt(self) -> bool:
        """
        Attempts to match the input sequence, starting at the beginning of the
        region, against the pattern.
        
         Like the .matches matches method, this method always starts
        at the beginning of the region; unlike that method, it does not
        require that the entire region be matched.
        
         If the match succeeds then more information can be obtained via the
        `start`, `end`, and `group` methods.  

        Returns
        - `True` if, and only if, a prefix of the input
                 sequence matches this matcher's pattern
        """
        ...


    @staticmethod
    def quoteReplacement(s: str) -> str:
        """
        Returns a literal replacement `String` for the specified
        `String`.
        
        This method produces a `String` that will work
        as a literal replacement `s` in the
        `appendReplacement` method of the Matcher class.
        The `String` produced will match the sequence of characters
        in `s` treated as a literal sequence. Slashes ('\') and
        dollar signs ('$') will be given no special meaning.

        Arguments
        - s: The string to be literalized

        Returns
        - A literal string replacement

        Since
        - 1.5
        """
        ...


    def appendReplacement(self, sb: "StringBuffer", replacement: str) -> "Matcher":
        """
        Implements a non-terminal append-and-replace step.
        
         This method performs the following actions: 
        
        <ol>
        
          -  It reads characters from the input sequence, starting at the
          append position, and appends them to the given string buffer.  It
          stops after reading the last character preceding the previous match,
          that is, the character at index .start()&nbsp;`-`&nbsp;`1`.  
        
          -  It appends the given replacement string to the string buffer.
          
        
          -  It sets the append position of this matcher to the index of
          the last character matched, plus one, that is, to .end().
          
        
        </ol>
        
         The replacement string may contain references to subsequences
        captured during the previous match: Each occurrence of
        `${`*name*`}` or `$`*g*
        will be replaced by the result of evaluating the corresponding
        .group(String) group(name) or .group(int) group(g)
        respectively. For `$`*g*,
        the first number after the `$` is always treated as part of
        the group reference. Subsequent numbers are incorporated into g if
        they would form a legal group reference. Only the numerals '0'
        through '9' are considered as potential components of the group
        reference. If the second group matched the string `"foo"`, for
        example, then passing the replacement string `"$2bar"` would
        cause `"foobar"` to be appended to the string buffer. A dollar
        sign (`$`) may be included as a literal in the replacement
        string by preceding it with a backslash (`\$`).
        
         Note that backslashes (`\`) and dollar signs (`$`) in
        the replacement string may cause the results to be different than if it
        were being treated as a literal replacement string. Dollar signs may be
        treated as references to captured subsequences as described above, and
        backslashes are used to escape literal characters in the replacement
        string.
        
         This method is intended to be used in a loop together with the
        .appendTail(StringBuffer) appendTail and .find() find
        methods.  The following code, for example, writes `one dog two dogs
        in the yard` to the standard-output stream: 
        
        <blockquote>```
        Pattern p = Pattern.compile("cat");
        Matcher m = p.matcher("one cat two cats in the yard");
        StringBuffer sb = new StringBuffer();
        while (m.find()) {
            m.appendReplacement(sb, "dog");
        }
        m.appendTail(sb);
        System.out.println(sb.toString());```</blockquote>

        Arguments
        - sb: The target string buffer
        - replacement: The replacement string

        Returns
        - This matcher

        Raises
        - IllegalStateException: If no match has yet been attempted,
                 or if the previous match operation failed
        - IllegalArgumentException: If the replacement string refers to a named-capturing
                 group that does not exist in the pattern
        - IndexOutOfBoundsException: If the replacement string refers to a capturing group
                 that does not exist in the pattern
        """
        ...


    def appendReplacement(self, sb: "StringBuilder", replacement: str) -> "Matcher":
        """
        Implements a non-terminal append-and-replace step.
        
         This method performs the following actions: 
        
        <ol>
        
          -  It reads characters from the input sequence, starting at the
          append position, and appends them to the given string builder.  It
          stops after reading the last character preceding the previous match,
          that is, the character at index .start()&nbsp;`-`&nbsp;`1`.  
        
          -  It appends the given replacement string to the string builder.
          
        
          -  It sets the append position of this matcher to the index of
          the last character matched, plus one, that is, to .end().
          
        
        </ol>
        
         The replacement string may contain references to subsequences
        captured during the previous match: Each occurrence of
        `$`*g* will be replaced by the result of
        evaluating .group(int) group`(`*g*`)`.
        The first number after the `$` is always treated as part of
        the group reference. Subsequent numbers are incorporated into g if
        they would form a legal group reference. Only the numerals '0'
        through '9' are considered as potential components of the group
        reference. If the second group matched the string `"foo"`, for
        example, then passing the replacement string `"$2bar"` would
        cause `"foobar"` to be appended to the string builder. A dollar
        sign (`$`) may be included as a literal in the replacement
        string by preceding it with a backslash (`\$`).
        
         Note that backslashes (`\`) and dollar signs (`$`) in
        the replacement string may cause the results to be different than if it
        were being treated as a literal replacement string. Dollar signs may be
        treated as references to captured subsequences as described above, and
        backslashes are used to escape literal characters in the replacement
        string.
        
         This method is intended to be used in a loop together with the
        .appendTail(StringBuilder) appendTail and
        .find() find methods. The following code, for example, writes
        `one dog two dogs in the yard` to the standard-output stream: 
        
        <blockquote>```
        Pattern p = Pattern.compile("cat");
        Matcher m = p.matcher("one cat two cats in the yard");
        StringBuilder sb = new StringBuilder();
        while (m.find()) {
            m.appendReplacement(sb, "dog");
        }
        m.appendTail(sb);
        System.out.println(sb.toString());```</blockquote>

        Arguments
        - sb: The target string builder
        - replacement: The replacement string

        Returns
        - This matcher

        Raises
        - IllegalStateException: If no match has yet been attempted,
                 or if the previous match operation failed
        - IllegalArgumentException: If the replacement string refers to a named-capturing
                 group that does not exist in the pattern
        - IndexOutOfBoundsException: If the replacement string refers to a capturing group
                 that does not exist in the pattern

        Since
        - 9
        """
        ...


    def appendTail(self, sb: "StringBuffer") -> "StringBuffer":
        """
        Implements a terminal append-and-replace step.
        
         This method reads characters from the input sequence, starting at
        the append position, and appends them to the given string buffer.  It is
        intended to be invoked after one or more invocations of the .appendReplacement(StringBuffer, String) appendReplacement method in
        order to copy the remainder of the input sequence.  

        Arguments
        - sb: The target string buffer

        Returns
        - The target string buffer
        """
        ...


    def appendTail(self, sb: "StringBuilder") -> "StringBuilder":
        """
        Implements a terminal append-and-replace step.
        
         This method reads characters from the input sequence, starting at
        the append position, and appends them to the given string builder.  It is
        intended to be invoked after one or more invocations of the .appendReplacement(StringBuilder, String)
        appendReplacement method in order to copy the remainder of the input
        sequence.  

        Arguments
        - sb: The target string builder

        Returns
        - The target string builder

        Since
        - 9
        """
        ...


    def replaceAll(self, replacement: str) -> str:
        """
        Replaces every subsequence of the input sequence that matches the
        pattern with the given replacement string.
        
         This method first resets this matcher.  It then scans the input
        sequence looking for matches of the pattern.  Characters that are not
        part of any match are appended directly to the result string; each match
        is replaced in the result by the replacement string.  The replacement
        string may contain references to captured subsequences as in the .appendReplacement appendReplacement method.
        
         Note that backslashes (`\`) and dollar signs (`$`) in
        the replacement string may cause the results to be different than if it
        were being treated as a literal replacement string. Dollar signs may be
        treated as references to captured subsequences as described above, and
        backslashes are used to escape literal characters in the replacement
        string.
        
         Given the regular expression `a*b`, the input
        `"aabfooaabfooabfoob"`, and the replacement string
        `"-"`, an invocation of this method on a matcher for that
        expression would yield the string `"-foo-foo-foo-"`.
        
         Invoking this method changes this matcher's state.  If the matcher
        is to be used in further matching operations then it should first be
        reset.  

        Arguments
        - replacement: The replacement string

        Returns
        - The string constructed by replacing each matching subsequence
                 by the replacement string, substituting captured subsequences
                 as needed
        """
        ...


    def replaceAll(self, replacer: "Function"["MatchResult", str]) -> str:
        """
        Replaces every subsequence of the input sequence that matches the
        pattern with the result of applying the given replacer function to the
        match result of this matcher corresponding to that subsequence.
        Exceptions thrown by the function are relayed to the caller.
        
         This method first resets this matcher.  It then scans the input
        sequence looking for matches of the pattern.  Characters that are not
        part of any match are appended directly to the result string; each match
        is replaced in the result by the applying the replacer function that
        returns a replacement string.  Each replacement string may contain
        references to captured subsequences as in the .appendReplacement
        appendReplacement method.
        
         Note that backslashes (`\`) and dollar signs (`$`) in
        a replacement string may cause the results to be different than if it
        were being treated as a literal replacement string. Dollar signs may be
        treated as references to captured subsequences as described above, and
        backslashes are used to escape literal characters in the replacement
        string.
        
         Given the regular expression `dog`, the input
        `"zzzdogzzzdogzzz"`, and the function
        `mr -> mr.group().toUpperCase()`, an invocation of this method on
        a matcher for that expression would yield the string
        `"zzzDOGzzzDOGzzz"`.
        
         Invoking this method changes this matcher's state.  If the matcher
        is to be used in further matching operations then it should first be
        reset.  
        
         The replacer function should not modify this matcher's state during
        replacement.  This method will, on a best-effort basis, throw a
        java.util.ConcurrentModificationException if such modification is
        detected.
        
         The state of each match result passed to the replacer function is
        guaranteed to be constant only for the duration of the replacer function
        call and only if the replacer function does not modify this matcher's
        state.

        Arguments
        - replacer: The function to be applied to the match result of this matcher
                that returns a replacement string.

        Returns
        - The string constructed by replacing each matching subsequence
                 with the result of applying the replacer function to that
                 matched subsequence, substituting captured subsequences as
                 needed.

        Raises
        - NullPointerException: if the replacer function is null
        - ConcurrentModificationException: if it is detected, on a
                best-effort basis, that the replacer function modified this
                matcher's state

        Since
        - 9

        Unknown Tags
        - This implementation applies the replacer function to this matcher, which
        is an instance of `MatchResult`.
        """
        ...


    def results(self) -> "Stream"["MatchResult"]:
        """
        Returns a stream of match results for each subsequence of the input
        sequence that matches the pattern.  The match results occur in the
        same order as the matching subsequences in the input sequence.
        
         Each match result is produced as if by .toMatchResult().
        
         This method does not reset this matcher.  Matching starts on
        initiation of the terminal stream operation either at the beginning of
        this matcher's region, or, if the matcher has not since been reset, at
        the first character not matched by a previous match.
        
         If the matcher is to be used for further matching operations after
        the terminal stream operation completes then it should be first reset.
        
         This matcher's state should not be modified during execution of the
        returned stream's pipeline.  The returned stream's source
        `Spliterator` is *fail-fast* and will, on a best-effort
        basis, throw a java.util.ConcurrentModificationException if such
        modification is detected.

        Returns
        - a sequential stream of match results.

        Since
        - 9
        """
        ...


    def replaceFirst(self, replacement: str) -> str:
        """
        Replaces the first subsequence of the input sequence that matches the
        pattern with the given replacement string.
        
         This method first resets this matcher.  It then scans the input
        sequence looking for a match of the pattern.  Characters that are not
        part of the match are appended directly to the result string; the match
        is replaced in the result by the replacement string.  The replacement
        string may contain references to captured subsequences as in the .appendReplacement appendReplacement method.
        
        Note that backslashes (`\`) and dollar signs (`$`) in
        the replacement string may cause the results to be different than if it
        were being treated as a literal replacement string. Dollar signs may be
        treated as references to captured subsequences as described above, and
        backslashes are used to escape literal characters in the replacement
        string.
        
         Given the regular expression `dog`, the input
        `"zzzdogzzzdogzzz"`, and the replacement string
        `"cat"`, an invocation of this method on a matcher for that
        expression would yield the string `"zzzcatzzzdogzzz"`.  
        
         Invoking this method changes this matcher's state.  If the matcher
        is to be used in further matching operations then it should first be
        reset.  

        Arguments
        - replacement: The replacement string

        Returns
        - The string constructed by replacing the first matching
                 subsequence by the replacement string, substituting captured
                 subsequences as needed
        """
        ...


    def replaceFirst(self, replacer: "Function"["MatchResult", str]) -> str:
        """
        Replaces the first subsequence of the input sequence that matches the
        pattern with the result of applying the given replacer function to the
        match result of this matcher corresponding to that subsequence.
        Exceptions thrown by the replace function are relayed to the caller.
        
         This method first resets this matcher.  It then scans the input
        sequence looking for a match of the pattern.  Characters that are not
        part of the match are appended directly to the result string; the match
        is replaced in the result by the applying the replacer function that
        returns a replacement string.  The replacement string may contain
        references to captured subsequences as in the .appendReplacement
        appendReplacement method.
        
        Note that backslashes (`\`) and dollar signs (`$`) in
        the replacement string may cause the results to be different than if it
        were being treated as a literal replacement string. Dollar signs may be
        treated as references to captured subsequences as described above, and
        backslashes are used to escape literal characters in the replacement
        string.
        
         Given the regular expression `dog`, the input
        `"zzzdogzzzdogzzz"`, and the function
        `mr -> mr.group().toUpperCase()`, an invocation of this method on
        a matcher for that expression would yield the string
        `"zzzDOGzzzdogzzz"`.
        
         Invoking this method changes this matcher's state.  If the matcher
        is to be used in further matching operations then it should first be
        reset.
        
         The replacer function should not modify this matcher's state during
        replacement.  This method will, on a best-effort basis, throw a
        java.util.ConcurrentModificationException if such modification is
        detected.
        
         The state of the match result passed to the replacer function is
        guaranteed to be constant only for the duration of the replacer function
        call and only if the replacer function does not modify this matcher's
        state.

        Arguments
        - replacer: The function to be applied to the match result of this matcher
                that returns a replacement string.

        Returns
        - The string constructed by replacing the first matching
                 subsequence with the result of applying the replacer function to
                 the matched subsequence, substituting captured subsequences as
                 needed.

        Raises
        - NullPointerException: if the replacer function is null
        - ConcurrentModificationException: if it is detected, on a
                best-effort basis, that the replacer function modified this
                matcher's state

        Since
        - 9

        Unknown Tags
        - This implementation applies the replacer function to this matcher, which
        is an instance of `MatchResult`.
        """
        ...


    def region(self, start: int, end: int) -> "Matcher":
        """
        Sets the limits of this matcher's region. The region is the part of the
        input sequence that will be searched to find a match. Invoking this
        method resets the matcher, and then sets the region to start at the
        index specified by the `start` parameter and end at the
        index specified by the `end` parameter.
        
        Depending on the transparency and anchoring being used (see
        .useTransparentBounds(boolean) useTransparentBounds and
        .useAnchoringBounds(boolean) useAnchoringBounds), certain
        constructs such as anchors may behave differently at or around the
        boundaries of the region.

        Arguments
        - start: The index to start searching at (inclusive)
        - end: The index to end searching at (exclusive)

        Returns
        - this matcher

        Raises
        - IndexOutOfBoundsException: If start or end is less than zero, if
                 start is greater than the length of the input sequence, if
                 end is greater than the length of the input sequence, or if
                 start is greater than end.

        Since
        - 1.5
        """
        ...


    def regionStart(self) -> int:
        """
        Reports the start index of this matcher's region. The
        searches this matcher conducts are limited to finding matches
        within .regionStart() regionStart (inclusive) and
        .regionEnd() regionEnd (exclusive).

        Returns
        - The starting point of this matcher's region

        Since
        - 1.5
        """
        ...


    def regionEnd(self) -> int:
        """
        Reports the end index (exclusive) of this matcher's region.
        The searches this matcher conducts are limited to finding matches
        within .regionStart() regionStart (inclusive) and
        .regionEnd() regionEnd (exclusive).

        Returns
        - the ending point of this matcher's region

        Since
        - 1.5
        """
        ...


    def hasTransparentBounds(self) -> bool:
        """
        Queries the transparency of region bounds for this matcher.
        
         This method returns `True` if this matcher uses
        *transparent* bounds, `False` if it uses *opaque*
        bounds.
        
         See .useTransparentBounds(boolean) useTransparentBounds for a
        description of transparent and opaque bounds.
        
         By default, a matcher uses opaque region boundaries.

        Returns
        - `True` iff this matcher is using transparent bounds,
                `False` otherwise.

        See
        - java.util.regex.Matcher.useTransparentBounds(boolean)

        Since
        - 1.5
        """
        ...


    def useTransparentBounds(self, b: bool) -> "Matcher":
        """
        Sets the transparency of region bounds for this matcher.
        
         Invoking this method with an argument of `True` will set this
        matcher to use *transparent* bounds. If the boolean
        argument is `False`, then *opaque* bounds will be used.
        
         Using transparent bounds, the boundaries of this
        matcher's region are transparent to lookahead, lookbehind,
        and boundary matching constructs. Those constructs can see beyond the
        boundaries of the region to see if a match is appropriate.
        
         Using opaque bounds, the boundaries of this matcher's
        region are opaque to lookahead, lookbehind, and boundary matching
        constructs that may try to see beyond them. Those constructs cannot
        look past the boundaries so they will fail to match anything outside
        of the region.
        
         By default, a matcher uses opaque bounds.

        Arguments
        - b: a boolean indicating whether to use opaque or transparent
                regions

        Returns
        - this matcher

        See
        - java.util.regex.Matcher.hasTransparentBounds

        Since
        - 1.5
        """
        ...


    def hasAnchoringBounds(self) -> bool:
        """
        Queries the anchoring of region bounds for this matcher.
        
         This method returns `True` if this matcher uses
        *anchoring* bounds, `False` otherwise.
        
         See .useAnchoringBounds(boolean) useAnchoringBounds for a
        description of anchoring bounds.
        
         By default, a matcher uses anchoring region boundaries.

        Returns
        - `True` iff this matcher is using anchoring bounds,
                `False` otherwise.

        See
        - java.util.regex.Matcher.useAnchoringBounds(boolean)

        Since
        - 1.5
        """
        ...


    def useAnchoringBounds(self, b: bool) -> "Matcher":
        """
        Sets the anchoring of region bounds for this matcher.
        
         Invoking this method with an argument of `True` will set this
        matcher to use *anchoring* bounds. If the boolean
        argument is `False`, then *non-anchoring* bounds will be
        used.
        
         Using anchoring bounds, the boundaries of this
        matcher's region match anchors such as ^ and $.
        
         Without anchoring bounds, the boundaries of this
        matcher's region will not match anchors such as ^ and $.
        
         By default, a matcher uses anchoring region boundaries.

        Arguments
        - b: a boolean indicating whether or not to use anchoring bounds.

        Returns
        - this matcher

        See
        - java.util.regex.Matcher.hasAnchoringBounds

        Since
        - 1.5
        """
        ...


    def toString(self) -> str:
        """
        Returns the string representation of this matcher. The
        string representation of a `Matcher` contains information
        that may be useful for debugging. The exact format is unspecified.

        Returns
        - The string representation of this matcher

        Since
        - 1.5
        """
        ...


    def hitEnd(self) -> bool:
        """
        Returns True if the end of input was hit by the search engine in
        the last match operation performed by this matcher.
        
        When this method returns True, then it is possible that more input
        would have changed the result of the last search.

        Returns
        - True iff the end of input was hit in the last match; False
                 otherwise

        Since
        - 1.5
        """
        ...


    def requireEnd(self) -> bool:
        """
        Returns True if more input could change a positive match into a
        negative one.
        
        If this method returns True, and a match was found, then more
        input could cause the match to be lost. If this method returns False
        and a match was found, then more input might change the match but the
        match won't be lost. If a match was not found, then requireEnd has no
        meaning.

        Returns
        - True iff more input could change a positive match into a
                 negative one.

        Since
        - 1.5
        """
        ...



"""
Python module generated from Java source file java.util.concurrent.ScheduledExecutorService

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util.concurrent import *
from typing import Any, Callable, Iterable, Tuple


class ScheduledExecutorService(ExecutorService):
    """
    An ExecutorService that can schedule commands to run after a given
    delay, or to execute periodically.
    
    The `schedule` methods create tasks with various delays
    and return a task object that can be used to cancel or check
    execution. The `scheduleAtFixedRate` and
    `scheduleWithFixedDelay` methods create and execute tasks
    that run periodically until cancelled.
    
    Commands submitted using the Executor.execute(Runnable)
    and ExecutorService `submit` methods are scheduled
    with a requested delay of zero. Zero and negative delays (but not
    periods) are also allowed in `schedule` methods, and are
    treated as requests for immediate execution.
    
    All `schedule` methods accept *relative* delays and
    periods as arguments, not absolute times or dates. It is a simple
    matter to transform an absolute time represented as a java.util.Date to the required form. For example, to schedule at
    a certain future `date`, you can use: `schedule(task,
    date.getTime() - System.currentTimeMillis(),
    TimeUnit.MILLISECONDS)`. Beware however that expiration of a
    relative delay need not coincide with the current `Date` at
    which the task is enabled due to network time synchronization
    protocols, clock drift, or other factors.
    
    The Executors class provides convenient factory methods for
    the ScheduledExecutorService implementations provided in this package.
    
    <h2>Usage Example</h2>
    
    Here is a class with a method that sets up a ScheduledExecutorService
    to beep every ten seconds for an hour:
    
    ``` `import static java.util.concurrent.TimeUnit.*;
    class BeeperControl {
      private final ScheduledExecutorService scheduler =
        Executors.newScheduledThreadPool(1);
    
      public void beepForAnHour() {
        Runnable beeper = () -> System.out.println("beep");
        ScheduledFuture<?> beeperHandle =
          scheduler.scheduleAtFixedRate(beeper, 10, 10, SECONDS);
        Runnable canceller = () -> beeperHandle.cancel(False);
        scheduler.schedule(canceller, 1, HOURS);`
    }}```

    Author(s)
    - Doug Lea

    Since
    - 1.5
    """

    def schedule(self, command: "Runnable", delay: int, unit: "TimeUnit") -> "ScheduledFuture"[Any]:
        """
        Submits a one-shot task that becomes enabled after the given delay.

        Arguments
        - command: the task to execute
        - delay: the time from now to delay execution
        - unit: the time unit of the delay parameter

        Returns
        - a ScheduledFuture representing pending completion of
                the task and whose `get()` method will return
                `null` upon completion

        Raises
        - RejectedExecutionException: if the task cannot be
                scheduled for execution
        - NullPointerException: if command or unit is null
        """
        ...


    def schedule(self, callable: "Callable"["V"], delay: int, unit: "TimeUnit") -> "ScheduledFuture"["V"]:
        """
        Submits a value-returning one-shot task that becomes enabled
        after the given delay.
        
        Type `<V>`: the type of the callable's result

        Arguments
        - callable: the function to execute
        - delay: the time from now to delay execution
        - unit: the time unit of the delay parameter

        Returns
        - a ScheduledFuture that can be used to extract result or cancel

        Raises
        - RejectedExecutionException: if the task cannot be
                scheduled for execution
        - NullPointerException: if callable or unit is null
        """
        ...


    def scheduleAtFixedRate(self, command: "Runnable", initialDelay: int, period: int, unit: "TimeUnit") -> "ScheduledFuture"[Any]:
        """
        Submits a periodic action that becomes enabled first after the
        given initial delay, and subsequently with the given period;
        that is, executions will commence after
        `initialDelay`, then `initialDelay + period`, then
        `initialDelay + 2 * period`, and so on.
        
        The sequence of task executions continues indefinitely until
        one of the following exceptional completions occur:
        
        - The task is Future.cancel explicitly cancelled
        via the returned future.
        - The executor terminates, also resulting in task cancellation.
        - An execution of the task throws an exception.  In this case
        calling Future.get() get on the returned future will throw
        ExecutionException, holding the exception as its cause.
        
        Subsequent executions are suppressed.  Subsequent calls to
        Future.isDone isDone() on the returned future will
        return `True`.
        
        If any execution of this task takes longer than its period, then
        subsequent executions may start late, but will not concurrently
        execute.

        Arguments
        - command: the task to execute
        - initialDelay: the time to delay first execution
        - period: the period between successive executions
        - unit: the time unit of the initialDelay and period parameters

        Returns
        - a ScheduledFuture representing pending completion of
                the series of repeated tasks.  The future's Future.get() get() method will never return normally,
                and will throw an exception upon task cancellation or
                abnormal termination of a task execution.

        Raises
        - RejectedExecutionException: if the task cannot be
                scheduled for execution
        - NullPointerException: if command or unit is null
        - IllegalArgumentException: if period less than or equal to zero
        """
        ...


    def scheduleWithFixedDelay(self, command: "Runnable", initialDelay: int, delay: int, unit: "TimeUnit") -> "ScheduledFuture"[Any]:
        """
        Submits a periodic action that becomes enabled first after the
        given initial delay, and subsequently with the given delay
        between the termination of one execution and the commencement of
        the next.
        
        The sequence of task executions continues indefinitely until
        one of the following exceptional completions occur:
        
        - The task is Future.cancel explicitly cancelled
        via the returned future.
        - The executor terminates, also resulting in task cancellation.
        - An execution of the task throws an exception.  In this case
        calling Future.get() get on the returned future will throw
        ExecutionException, holding the exception as its cause.
        
        Subsequent executions are suppressed.  Subsequent calls to
        Future.isDone isDone() on the returned future will
        return `True`.

        Arguments
        - command: the task to execute
        - initialDelay: the time to delay first execution
        - delay: the delay between the termination of one
        execution and the commencement of the next
        - unit: the time unit of the initialDelay and delay parameters

        Returns
        - a ScheduledFuture representing pending completion of
                the series of repeated tasks.  The future's Future.get() get() method will never return normally,
                and will throw an exception upon task cancellation or
                abnormal termination of a task execution.

        Raises
        - RejectedExecutionException: if the task cannot be
                scheduled for execution
        - NullPointerException: if command or unit is null
        - IllegalArgumentException: if delay less than or equal to zero
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.entity.PlayerLeashEntityEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import Entity
from org.bukkit.entity import Player
from org.bukkit.event import Cancellable
from org.bukkit.event import Event
from org.bukkit.event import HandlerList
from org.bukkit.event.entity import *
from org.bukkit.inventory import EquipmentSlot
from typing import Any, Callable, Iterable, Tuple


class PlayerLeashEntityEvent(Event, Cancellable):
    """
    Called immediately prior to a creature being leashed by a player.
    """

    def __init__(self, what: "Entity", leashHolder: "Entity", leasher: "Player", hand: "EquipmentSlot"):
        ...


    def __init__(self, what: "Entity", leashHolder: "Entity", leasher: "Player"):
        ...


    def getLeashHolder(self) -> "Entity":
        """
        Returns the entity that is holding the leash.

        Returns
        - The leash holder
        """
        ...


    def getEntity(self) -> "Entity":
        """
        Returns the entity being leashed.

        Returns
        - The entity
        """
        ...


    def getPlayer(self) -> "Player":
        """
        Returns the player involved in this event

        Returns
        - Player who is involved in this event
        """
        ...


    def getHand(self) -> "EquipmentSlot":
        """
        Returns the hand used by the player to leash the entity.

        Returns
        - the hand
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...


    def isCancelled(self) -> bool:
        ...


    def setCancelled(self, cancel: bool) -> None:
        ...



"""
Python module generated from Java source file com.google.common.hash.Funnel

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import Beta
from com.google.common.hash import *
from com.google.errorprone.annotations import DoNotMock
from java.io import Serializable
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class Funnel(Serializable):
    """
    An object which can send data from an object of type `T` into a `PrimitiveSink`.
    Implementations for common types can be found in Funnels.
    
    Note that serialization of BloomFilter bloom filters requires the proper
    serialization of funnels. When possible, it is recommended that funnels be implemented as a
    single-element enum to maintain serialization guarantees. See Effective Java (2nd Edition), Item
    3: "Enforce the singleton property with a private constructor or an enum type". For example:
    
    ````public enum PersonFunnel implements Funnel<Person> {
      INSTANCE;
      public void funnel(Person person, PrimitiveSink into) {
        into.putUnencodedChars(person.getFirstName())
            .putUnencodedChars(person.getLastName())
            .putInt(person.getAge());`
    }
    }```

    Author(s)
    - Dimitris Andreou

    Since
    - 11.0
    """

    def funnel(self, from: "T", into: "PrimitiveSink") -> None:
        """
        Sends a stream of data from the `from` object into the sink `into`. There is no
        requirement that this data be complete enough to fully reconstitute the object later.

        Since
        - 12.0 (in Guava 11.0, `PrimitiveSink` was named `Sink`)
        """
        ...



"""
Python module generated from Java source file java.util.function.UnaryOperator

Java source file obtained from artifact jdk version jdk

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from java.util.function import *
from typing import Any, Callable, Iterable, Tuple


class UnaryOperator(Function):
    """
    Represents an operation on a single operand that produces a result of the
    same type as its operand.  This is a specialization of `Function` for
    the case where the operand and result are of the same type.
    
    This is a <a href="package-summary.html">functional interface</a>
    whose functional method is .apply(Object).
    
    Type `<T>`: the type of the operand and result of the operator

    See
    - Function

    Since
    - 1.8
    """

    @staticmethod
    def identity() -> "UnaryOperator"["T"]:
        """
        Returns a unary operator that always returns its input argument.
        
        Type `<T>`: the type of the input and output of the operator

        Returns
        - a unary operator that always returns its input argument
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.AbstractMultimap

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.collect import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.errorprone.annotations.concurrent import LazyInit
from com.google.j2objc.annotations import WeakOuter
from java.util import AbstractCollection
from java.util import Iterator
from java.util import Spliterator
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class AbstractMultimap(Multimap):
    """
    A skeleton `Multimap` implementation, not necessarily in terms of a `Map`.

    Author(s)
    - Louis Wasserman
    """

    def isEmpty(self) -> bool:
        ...


    def containsValue(self, value: "Object") -> bool:
        ...


    def containsEntry(self, key: "Object", value: "Object") -> bool:
        ...


    def remove(self, key: "Object", value: "Object") -> bool:
        ...


    def put(self, key: "K", value: "V") -> bool:
        ...


    def putAll(self, key: "K", values: Iterable["V"]) -> bool:
        ...


    def putAll(self, multimap: "Multimap"["K", "V"]) -> bool:
        ...


    def replaceValues(self, key: "K", values: Iterable["V"]) -> Iterable["V"]:
        ...


    def entries(self) -> Iterable["Entry"["K", "V"]]:
        ...


    def keySet(self) -> set["K"]:
        ...


    def keys(self) -> "Multiset"["K"]:
        ...


    def values(self) -> Iterable["V"]:
        ...


    def asMap(self) -> dict["K", Iterable["V"]]:
        ...


    def equals(self, object: "Object") -> bool:
        ...


    def hashCode(self) -> int:
        """
        Returns the hash code for this multimap.
        
        The hash code of a multimap is defined as the hash code of the map view, as returned by
        Multimap.asMap.

        See
        - Map.hashCode
        """
        ...


    def toString(self) -> str:
        """
        Returns a string representation of the multimap, generated by calling `toString` on the
        map returned by Multimap.asMap.

        Returns
        - a string representation of the multimap
        """
        ...



"""
Python module generated from Java source file com.google.common.collect.ForwardingMap

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.base import Objects
from com.google.common.collect import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from java.util import Iterator
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class ForwardingMap(ForwardingObject, Map):
    """
    A map which forwards all its method calls to another map. Subclasses should override one or more
    methods to modify the behavior of the backing map as desired per the <a
    href="http://en.wikipedia.org/wiki/Decorator_pattern">decorator pattern</a>.
    
    **Warning:** The methods of `ForwardingMap` forward *indiscriminately* to the
    methods of the delegate. For example, overriding .put alone *will not* change the
    behavior of .putAll, which can lead to unexpected behavior. In this case, you should
    override `putAll` as well, either providing your own implementation, or delegating to the
    provided `standardPutAll` method.
    
    **`default` method warning:** This class does *not* forward calls to `default` methods. Instead, it inherits their default implementations. When those implementations
    invoke methods, they invoke methods on the `ForwardingMap`.
    
    Each of the `standard` methods, where appropriate, use Objects.equal to test
    equality for both keys and values. This may not be the desired behavior for map implementations
    that use non-standard notions of key equality, such as a `SortedMap` whose comparator is
    not consistent with `equals`.
    
    The `standard` methods and the collection views they return are not guaranteed to be
    thread-safe, even when all of the methods that they depend on are thread-safe.

    Author(s)
    - Louis Wasserman

    Since
    - 2.0
    """

    def size(self) -> int:
        ...


    def isEmpty(self) -> bool:
        ...


    def remove(self, key: "Object") -> "V":
        ...


    def clear(self) -> None:
        ...


    def containsKey(self, key: "Object") -> bool:
        ...


    def containsValue(self, value: "Object") -> bool:
        ...


    def get(self, key: "Object") -> "V":
        ...


    def put(self, key: "K", value: "V") -> "V":
        ...


    def putAll(self, map: dict["K", "V"]) -> None:
        ...


    def keySet(self) -> set["K"]:
        ...


    def values(self) -> Iterable["V"]:
        ...


    def entrySet(self) -> set["Entry"["K", "V"]]:
        ...


    def equals(self, object: "Object") -> bool:
        ...


    def hashCode(self) -> int:
        ...



"""
Python module generated from Java source file org.bukkit.event.block.BlockFormEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import Block
from org.bukkit.block import BlockState
from org.bukkit.event import HandlerList
from org.bukkit.event.block import *
from typing import Any, Callable, Iterable, Tuple


class BlockFormEvent(BlockGrowEvent):
    """
    Called when a block is formed or spreads based on world conditions.
    
    Use BlockSpreadEvent to catch blocks that actually spread and don't
    just "randomly" form.
    
    Examples:
    
    - Snow forming due to a snow storm.
    - Ice forming in a snowy Biome like Taiga or Tundra.
    -  Obsidian / Cobblestone forming due to contact with water.
    -  Concrete forming due to mixing of concrete powder and water.
    
    
    If a Block Form event is cancelled, the block will not be formed.

    See
    - BlockSpreadEvent
    """

    def __init__(self, block: "Block", newState: "BlockState"):
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file com.google.common.reflect.MutableTypeToInstanceMap

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.collect import ForwardingMap
from com.google.common.collect import ForwardingMapEntry
from com.google.common.collect import ForwardingSet
from com.google.common.collect import Iterators
from com.google.common.collect import Maps
from com.google.common.reflect import *
from com.google.errorprone.annotations import CanIgnoreReturnValue
from com.google.errorprone.annotations import DoNotCall
from java.util import Iterator
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import NonNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class MutableTypeToInstanceMap(ForwardingMap, TypeToInstanceMap):
    """
    A mutable type-to-instance map. See also ImmutableTypeToInstanceMap.

    Author(s)
    - Ben Yu

    Since
    - 13.0
    """

    def getInstance(self, type: type["T"]) -> "T":
        ...


    def getInstance(self, type: "TypeToken"["T"]) -> "T":
        ...


    def putInstance(self, type: type["T"], value: "T") -> "T":
        ...


    def putInstance(self, type: "TypeToken"["T"], value: "T") -> "T":
        ...


    def put(self, key: "TypeToken"["B"], value: "B") -> "B":
        """
        Not supported. Use .putInstance instead.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - unsupported operation
        """
        ...


    def putAll(self, map: dict["TypeToken"["B"], "B"]) -> None:
        """
        Not supported. Use .putInstance instead.

        Raises
        - UnsupportedOperationException: always

        Deprecated
        - unsupported operation
        """
        ...


    def entrySet(self) -> set["Entry"["TypeToken"["B"], "B"]]:
        ...



"""
Python module generated from Java source file com.google.common.collect.Synchronized

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtCompatible
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.annotations import VisibleForTesting
from com.google.common.collect import *
from com.google.j2objc.annotations import RetainedWith
from java.io import IOException
from java.io import ObjectOutputStream
from java.io import Serializable
from java.util import Comparator
from java.util import Deque
from java.util import Iterator
from java.util import ListIterator
from java.util import NavigableMap
from java.util import NavigableSet
from java.util import Queue
from java.util import RandomAccess
from java.util import SortedMap
from java.util import SortedSet
from java.util import Spliterator
from java.util.function import BiConsumer
from java.util.function import BiFunction
from java.util.function import Consumer
from java.util.function import Function
from java.util.function import Predicate
from java.util.function import UnaryOperator
from java.util.stream import Stream
from javax.annotation import CheckForNull
from org.checkerframework.checker.nullness.qual import NonNull
from org.checkerframework.checker.nullness.qual import Nullable
from typing import Any, Callable, Iterable, Tuple


class Synchronized:
    """
    Synchronized collection views. The returned synchronized collection views are serializable if the
    backing collection and the mutex are serializable.
    
    If `null` is passed as the `mutex` parameter to any of this class's top-level
    methods or inner class constructors, the created object uses itself as the synchronization mutex.
    
    This class should be used by other collection classes only.

    Author(s)
    - Jared Levy
    """





"""
Python module generated from Java source file org.yaml.snakeyaml.extensions.compactnotation.CompactData

Java source file obtained from artifact snakeyaml version 2.2

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.yaml.snakeyaml.extensions.compactnotation import *
from typing import Any, Callable, Iterable, Tuple


class CompactData:
    """
    Custom data structure to support compact notation
    https://bitbucket.org/snakeyaml/snakeyaml/wiki/CompactObjectNotation
    """

    def __init__(self, prefix: str):
        """
        Create

        Arguments
        - prefix: - by default is serves as a full class Name, but it can be changed
        """
        ...


    def getPrefix(self) -> str:
        """
        getter

        Returns
        - prefix from the document
        """
        ...


    def getProperties(self) -> dict[str, str]:
        """
        Getter

        Returns
        - properties
        """
        ...


    def getArguments(self) -> list[str]:
        """
        getter

        Returns
        - arguments
        """
        ...


    def toString(self) -> str:
        """
        visual representation

        Returns
        - readable data
        """
        ...



"""
Python module generated from Java source file com.google.common.hash.LittleEndianByteArray

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.hash import *
from com.google.common.primitives import Longs
from java.lang.reflect import Field
from java.security import AccessController
from java.security import PrivilegedActionException
from java.security import PrivilegedExceptionAction
from sun.misc import Unsafe
from typing import Any, Callable, Iterable, Tuple


class LittleEndianByteArray:
    """
    Utility functions for loading and storing values from a byte array.

    Author(s)
    - Kyle Maddison
    """





"""
Python module generated from Java source file org.bukkit.entity.Bee

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit import Location
from org.bukkit.entity import *
from typing import Any, Callable, Iterable, Tuple


class Bee(Animals):
    """
    Represents a Bee.
    """

    def getHive(self) -> "Location":
        """
        Get the bee's hive location.

        Returns
        - hive location or null
        """
        ...


    def setHive(self, location: "Location") -> None:
        """
        Set the bee's hive location.

        Arguments
        - location: or null
        """
        ...


    def getFlower(self) -> "Location":
        """
        Get the bee's flower location.

        Returns
        - flower location or null
        """
        ...


    def setFlower(self, location: "Location") -> None:
        """
        Set the bee's flower location.

        Arguments
        - location: or null
        """
        ...


    def hasNectar(self) -> bool:
        """
        Get if the bee has nectar.

        Returns
        - nectar
        """
        ...


    def setHasNectar(self, nectar: bool) -> None:
        """
        Set if the bee has nectar.

        Arguments
        - nectar: whether the entity has nectar
        """
        ...


    def hasStung(self) -> bool:
        """
        Get if the bee has stung.

        Returns
        - has stung
        """
        ...


    def setHasStung(self, stung: bool) -> None:
        """
        Set if the bee has stung.

        Arguments
        - stung: has stung
        """
        ...


    def getAnger(self) -> int:
        """
        Get the bee's anger level.

        Returns
        - anger level
        """
        ...


    def setAnger(self, anger: int) -> None:
        """
        Set the bee's new anger level.

        Arguments
        - anger: new anger
        """
        ...


    def getCannotEnterHiveTicks(self) -> int:
        """
        Get the amount of ticks the bee cannot enter the hive for.

        Returns
        - Ticks the bee cannot enter a hive for
        """
        ...


    def setCannotEnterHiveTicks(self, ticks: int) -> None:
        """
        Set the amount of ticks the bee cannot enter a hive for.

        Arguments
        - ticks: Ticks the bee cannot enter a hive for
        """
        ...



"""
Python module generated from Java source file org.bukkit.event.entity.EntityPoseChangeEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import Entity
from org.bukkit.entity import Pose
from org.bukkit.event import HandlerList
from org.bukkit.event.entity import *
from typing import Any, Callable, Iterable, Tuple


class EntityPoseChangeEvent(EntityEvent):
    """
    Called when an entity changes its pose.

    See
    - Entity.getPose()
    """

    def __init__(self, who: "Entity", pose: "Pose"):
        ...


    def getPose(self) -> "Pose":
        """
        Gets the entity's new pose.

        Returns
        - the new pose
        """
        ...


    def getHandlers(self) -> "HandlerList":
        ...


    @staticmethod
    def getHandlerList() -> "HandlerList":
        ...



"""
Python module generated from Java source file org.bukkit.material.Directional

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.block import BlockFace
from org.bukkit.material import *
from typing import Any, Callable, Iterable, Tuple


class Directional:

    def setFacingDirection(self, face: "BlockFace") -> None:
        """
        Sets the direction that this block is facing in

        Arguments
        - face: The facing direction
        """
        ...


    def getFacing(self) -> "BlockFace":
        """
        Gets the direction this block is facing

        Returns
        - the direction this block is facing
        """
        ...



"""
Python module generated from Java source file net.md_5.bungee.api.ChatColor

Java source file obtained from artifact bungeecord-chat version 1.20-R0.2-20240119.213604-65

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.base import Preconditions
from java.util import Locale
from java.util import Objects
from java.util.regex import Pattern
from net.md_5.bungee.api import *
from typing import Any, Callable, Iterable, Tuple


class ChatColor:
    """
    Simplistic enumeration of all supported color values for chat.
    """

    COLOR_CHAR = '\u00A7'
    """
    The special character which prefixes all chat colour codes. Use this if
    you need to dynamically convert colour codes from your custom format.
    """
    ALL_CODES = "0123456789AaBbCcDdEeFfKkLlMmNnOoRrXx"
    STRIP_COLOR_PATTERN = Pattern.compile("(?i)" + String.valueOf(COLOR_CHAR) + "[0-9A-FK-ORX]")
    """
    Pattern to remove all colour codes.
    """
    BLACK = ChatColor('0', "black", Color(0x000000))
    """
    Represents black.
    """
    DARK_BLUE = ChatColor('1', "dark_blue", Color(0x0000AA))
    """
    Represents dark blue.
    """
    DARK_GREEN = ChatColor('2', "dark_green", Color(0x00AA00))
    """
    Represents dark green.
    """
    DARK_AQUA = ChatColor('3', "dark_aqua", Color(0x00AAAA))
    """
    Represents dark blue (aqua).
    """
    DARK_RED = ChatColor('4', "dark_red", Color(0xAA0000))
    """
    Represents dark red.
    """
    DARK_PURPLE = ChatColor('5', "dark_purple", Color(0xAA00AA))
    """
    Represents dark purple.
    """
    GOLD = ChatColor('6', "gold", Color(0xFFAA00))
    """
    Represents gold.
    """
    GRAY = ChatColor('7', "gray", Color(0xAAAAAA))
    """
    Represents gray.
    """
    DARK_GRAY = ChatColor('8', "dark_gray", Color(0x555555))
    """
    Represents dark gray.
    """
    BLUE = ChatColor('9', "blue", Color(0x5555FF))
    """
    Represents blue.
    """
    GREEN = ChatColor('a', "green", Color(0x55FF55))
    """
    Represents green.
    """
    AQUA = ChatColor('b', "aqua", Color(0x55FFFF))
    """
    Represents aqua.
    """
    RED = ChatColor('c', "red", Color(0xFF5555))
    """
    Represents red.
    """
    LIGHT_PURPLE = ChatColor('d', "light_purple", Color(0xFF55FF))
    """
    Represents light purple.
    """
    YELLOW = ChatColor('e', "yellow", Color(0xFFFF55))
    """
    Represents yellow.
    """
    WHITE = ChatColor('f', "white", Color(0xFFFFFF))
    """
    Represents white.
    """
    MAGIC = ChatColor('k', "obfuscated")
    """
    Represents magical characters that change around randomly.
    """
    BOLD = ChatColor('l', "bold")
    """
    Makes the text bold.
    """
    STRIKETHROUGH = ChatColor('m', "strikethrough")
    """
    Makes a line appear through the text.
    """
    UNDERLINE = ChatColor('n', "underline")
    """
    Makes the text appear underlined.
    """
    ITALIC = ChatColor('o', "italic")
    """
    Makes the text italic.
    """
    RESET = ChatColor('r', "reset")
    """
    Resets all previous chat colors or formats.
    """


    def hashCode(self) -> int:
        ...


    def equals(self, obj: "Object") -> bool:
        ...


    def toString(self) -> str:
        ...


    @staticmethod
    def stripColor(input: str) -> str:
        """
        Strips the given message of all color codes

        Arguments
        - input: String to strip of color

        Returns
        - A copy of the input string, without any coloring
        """
        ...


    @staticmethod
    def translateAlternateColorCodes(altColorChar: str, textToTranslate: str) -> str:
        ...


    @staticmethod
    def getByChar(code: str) -> "ChatColor":
        """
        Get the colour represented by the specified code.

        Arguments
        - code: the code to search for

        Returns
        - the mapped colour, or null if non exists
        """
        ...


    @staticmethod
    def of(color: "Color") -> "ChatColor":
        ...


    @staticmethod
    def of(string: str) -> "ChatColor":
        ...


    @staticmethod
    def valueOf(name: str) -> "ChatColor":
        """
        See Enum.valueOf(java.lang.Class, java.lang.String).

        Arguments
        - name: color name

        Returns
        - ChatColor

        Deprecated
        - holdover from when this class was an enum
        """
        ...


    @staticmethod
    def values() -> list["ChatColor"]:
        """
        Get an array of all defined colors and formats.

        Returns
        - copied array of all colors and formats

        Deprecated
        - holdover from when this class was an enum
        """
        ...


    def name(self) -> str:
        """
        See Enum.name().

        Returns
        - constant name

        Deprecated
        - holdover from when this class was an enum
        """
        ...


    def ordinal(self) -> int:
        """
        See Enum.ordinal().

        Returns
        - ordinal

        Deprecated
        - holdover from when this class was an enum
        """
        ...



"""
Python module generated from Java source file org.bukkit.plugin.messaging.PluginMessageListenerRegistration

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.plugin import Plugin
from org.bukkit.plugin.messaging import *
from typing import Any, Callable, Iterable, Tuple


class PluginMessageListenerRegistration:
    """
    Contains information about a Plugins registration to a plugin
    channel.
    """

    def __init__(self, messenger: "Messenger", plugin: "Plugin", channel: str, listener: "PluginMessageListener"):
        ...


    def getChannel(self) -> str:
        """
        Gets the plugin channel that this registration is about.

        Returns
        - Plugin channel.
        """
        ...


    def getListener(self) -> "PluginMessageListener":
        """
        Gets the registered listener described by this registration.

        Returns
        - Registered listener.
        """
        ...


    def getPlugin(self) -> "Plugin":
        """
        Gets the plugin that this registration is for.

        Returns
        - Registered plugin.
        """
        ...


    def isValid(self) -> bool:
        """
        Checks if this registration is still valid.

        Returns
        - True if this registration is still valid, otherwise False.
        """
        ...


    def equals(self, obj: "Object") -> bool:
        ...


    def hashCode(self) -> int:
        ...



"""
Python module generated from Java source file org.bukkit.event.entity.EntityKnockbackByEntityEvent

Java source file obtained from artifact spigot-api version 1.21.4-R0.1-20250303.102353-42

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from org.bukkit.entity import Entity
from org.bukkit.entity import LivingEntity
from org.bukkit.event.entity import *
from org.bukkit.util import Vector
from typing import Any, Callable, Iterable, Tuple


class EntityKnockbackByEntityEvent(EntityKnockbackEvent):
    """
    Called when an entity receives knockback from another entity.
    """

    def __init__(self, entity: "LivingEntity", source: "Entity", cause: "KnockbackCause", force: float, rawKnockback: "Vector", knockback: "Vector"):
        ...


    def getSourceEntity(self) -> "Entity":
        """
        Get the entity that has caused knockback to the defender.

        Returns
        - entity that caused knockback
        """
        ...



"""
Python module generated from Java source file com.google.common.base.FinalizableReferenceQueue

Java source file obtained from artifact guava version 33.3.1-jre

Because this Python module is automatically generated, it may contain errors
and/or code that cannot be parsed. Please report these issues at
https://github.com/magicmq/docs-translator/issues
"""
from com.google.common.annotations import GwtIncompatible
from com.google.common.annotations import J2ktIncompatible
from com.google.common.annotations import VisibleForTesting
from com.google.common.base import *
from java.io import Closeable
from java.io import FileNotFoundException
from java.io import IOException
from java.lang.ref import PhantomReference
from java.lang.ref import Reference
from java.lang.ref import ReferenceQueue
from java.lang.reflect import Method
from java.net import URL
from java.net import URLClassLoader
from javax.annotation import CheckForNull
from typing import Any, Callable, Iterable, Tuple


class FinalizableReferenceQueue(Closeable):
    """
    A reference queue with an associated background thread that dequeues references and invokes
    FinalizableReference.finalizeReferent() on them.
    
    Keep a strong reference to this object until all of the associated referents have been
    finalized. If this object is garbage collected earlier, the backing thread will not invoke `finalizeReferent()` on the remaining references.
    
    As an example of how this is used, imagine you have a class `MyServer` that creates a
    java.net.ServerSocket ServerSocket, and you would like to ensure that the `ServerSocket` is closed even if the `MyServer` object is garbage-collected without calling
    its `close` method. You *could* use a finalizer to accomplish this, but that has a
    number of well-known problems. Here is how you might use this class instead:
    
    ````public class MyServer implements Closeable {
      private static final FinalizableReferenceQueue frq = new FinalizableReferenceQueue();
      // You might also share this between several objects.
    
      private static final Set<Reference<?>> references = Sets.newConcurrentHashSet();
      // This ensures that the FinalizablePhantomReference itself is not garbage-collected.
    
      private final ServerSocket serverSocket;
    
      private MyServer(...) {
        ...
        this.serverSocket = new ServerSocket(...);
        ...`
    
      public static MyServer create(...) {
        MyServer myServer = new MyServer(...);
        final ServerSocket serverSocket = myServer.serverSocket;
        Reference<?> reference = new FinalizablePhantomReference<MyServer>(myServer, frq) {
          public void finalizeReferent() {
            references.remove(this):
            if (!serverSocket.isClosed()) {
              ...log a message about how nobody called close()...
              try {
                serverSocket.close();
              } catch (IOException e) {
                ...
              }
            }
          }
        };
        references.add(reference);
        return myServer;
      }
    
      public void close() {
        serverSocket.close();
      }
    }
    }```

    Author(s)
    - Bob Lee

    Since
    - 2.0
    """

    def __init__(self):
        """
        Constructs a new queue.
        """
        ...


    def close(self) -> None:
        ...
